@@ -57,7 +57,9 @@ test_that("missing values work", {
 
 test_that("invalid inputs are caught", {
   expect_warning(ip_interface("192.168.0.1"))
-  expect_error(ip_interface(ip_address("192.168.0.1"), 24.5), "`prefix_length` must be an integer vector")
+  expect_snapshot(error = TRUE, {
+    ip_interface(ip_address("192.168.0.1"), 24.5)
+  })
   expect_warning(ip_interface(ip_address("192.168.0.1"), -1L))
 })
 
